/*
 * Example Code for the Paper
 *
 * "Mesh Saliency via Local Curvature Entropy", Eurographics 2016
 *
 * by M. Limper, A. Kuijper and D. Fellner
 *
 */

#include "Histogram.h"

#include <float.h>
#include <algorithm>


namespace lce
{

//------------------------------------------------------------------------------------------------------------------

Histogram::Histogram()
    : _totalCount(0), _min(FLT_MAX), _max(-FLT_MAX)
{
}

//------------------------------------------------------------------------------------------------------------------

void Histogram::add(float value)
{
    _min = std::min(value, _min);
    _max = std::max(value, _max);

    ++_count[value];
    ++_totalCount;
}

//------------------------------------------------------------------------------------------------------------------

float Histogram::getPercentile(float p) const
{
    if (p == 0.0f)
        return _min;

    if (p == 1.0f)
        return _max;

    std::map<float, unsigned>::const_iterator mIt, mEnd;

    unsigned n = 0;

    for (mIt = _count.begin(), mEnd = _count.end(); mIt != mEnd; ++mIt)
    {
        if (static_cast<float>(n) / _totalCount >= p)
        {
            return mIt->first;
        }

        n += mIt->second;
    }

    return _max;
}

//------------------------------------------------------------------------------------------------------------------

}
