/*
 * Example Code for the Paper
 *
 * "Mesh Saliency via Local Curvature Entropy", Eurographics 2016
 *
 * by M. Limper, A. Kuijper and D. Fellner
 *
 */

#include <iostream>

#include "lce.h"
#include "meshIO.h"


int main(int argc, char * argv[])
{
    std::cout << std::endl;

    std::cout << "LCE Mesh Saliency Command Line Tool" << std::endl;
    std::cout << "After computing LCE, the output mesh will have " << std::endl
              << "* per-vertex color mapping, indicating saliency, and"          << std::endl
              << "* a 'quality' property, containing normalized saliency values" << std::endl;

    std::cout << std::endl;

    if (argc < 3)
    {
        std::cout << "Usage: " << std::endl << argv[0] << " <input-file> <output-file>" << std::endl;
        std::cout << std::endl;

        return 0;
    }


    // read mesh from given input file (format must be supported by OpenMesh)

    const std::string inputFile = argv[1];

    lce::TriMesh mesh;

    std::cout << "Loading input file \"" << inputFile << "\"" << std::endl;

    if (!lce::loadFile(mesh, inputFile))
    {
        return 1;
    }


    // compute LCE

    std::cout << "Estimating mesh saliency (LCE)" << std::endl;

    lce::estimateSaliency(mesh);


    // write mesh to given output file (format must be supported by OpenMesh)

    const std::string outputFile = argv[2];

    std::cout << "Saving output file \"" << outputFile << "\"" << std::endl;

    if (!lce::saveFile(mesh, outputFile))
    {
        return 1;
    }


    return 0;
}
